Class: Edoxen::Contact
- Inherits:
-
Lutaml::Model::Serializable
- Object
- Lutaml::Model::Serializable
- Edoxen::Contact
- Defined in:
- lib/edoxen/contact.rb
Overview
VCARD-like abstract contact. Generalises Person for cases where the contact may be a person, an organisation, a department, a role ("Secretariat"), or any other entity with a name and one or more communication channels.
Use Contact where the kind of contact is open or mixed (meeting local-contact, meeting-series organiser, host-ref contact). Use Person (which inherits from Contact) where the contact is specifically an individual with identity (officer, attendee, voter).