Class: Edoxen::HostRef
- Inherits:
-
Lutaml::Model::Serializable
- Object
- Lutaml::Model::Serializable
- Edoxen::HostRef
- Defined in:
- lib/edoxen/host_ref.rb,
sig/edoxen.rbs
Overview
Typed reference to an organization that hosts or co-organizes a
meeting. ref is a stable identifier into an external registry
(national_bodies.yml, liaisons.yml, associates.yml in ISO/TC 154);
type discriminates which registry.
Instance Attribute Summary collapse
-
#contact ⇒ Person?
readonly
Returns the value of attribute contact.
-
#ref ⇒ String?
readonly
Returns the value of attribute ref.
-
#role ⇒ String?
readonly
Returns the value of attribute role.
-
#type ⇒ String?
readonly
Returns the value of attribute type.
Instance Attribute Details
#contact ⇒ Person? (readonly)
Returns the value of attribute contact.
101 102 103 |
# File 'sig/edoxen.rbs', line 101 def contact @contact end |
#ref ⇒ String? (readonly)
Returns the value of attribute ref.
98 99 100 |
# File 'sig/edoxen.rbs', line 98 def ref @ref end |
#role ⇒ String? (readonly)
Returns the value of attribute role.
100 101 102 |
# File 'sig/edoxen.rbs', line 100 def role @role end |
#type ⇒ String? (readonly)
Returns the value of attribute type.
99 100 101 |
# File 'sig/edoxen.rbs', line 99 def type @type end |